gemini

package
v0.3.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const ProviderName = "gemini_cli"

Variables

This section is empty.

Functions

func ExtractSessionID

func ExtractSessionID(sourceKey string) string

ExtractSessionID extracts a session ID from a Gemini session file path.

func SerializeToolUses

func SerializeToolUses(tus []ToolUse, contentTypes []string) sql.NullString

SerializeToolUses returns tool uses and content types as a JSON NullString.

func Truncate

func Truncate(s string, max int) string

Truncate trims and limits a string to max characters.

Types

type GeminiMessage

type GeminiMessage = geminiMessage

GeminiMessage aliases geminiMessage for hook integration.

type GeminiTranscript

type GeminiTranscript = geminiTranscript

GeminiTranscript aliases geminiTranscript for hook integration.

func ParseTranscript

func ParseTranscript(data []byte) (*GeminiTranscript, error)

ParseTranscript parses a Gemini session JSON file.

type ToolUse

type ToolUse = toolUse

ToolUse aliases toolUse for hook integration.

func ExtractToolUses

func ExtractToolUses(msg GeminiMessage) []ToolUse

ExtractToolUses extracts tool use entries from a Gemini message.

Jump to