providers

package
v0.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 14, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package providers builds the provider registries used by the CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewHookRegistry

func NewHookRegistry() *hooks.Registry

NewHookRegistry returns all hook providers supported by the CLI. Registry.List returns them in canonical order.

func NewWriterRegistry

func NewWriterRegistry() *llm.WriterRegistry

NewWriterRegistry returns the CLI's LLM writers in fallback order. The first available writer to complete successfully wins.

Types

This section is empty.

Jump to