commands

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2026 License: MIT Imports: 42 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

func NewAgentsCmd

func NewAgentsCmd(rootOpts *RootOptions) *cobra.Command

func NewAuthCmd

func NewAuthCmd() *cobra.Command

func NewAutoImplementationSummaryCmd added in v0.2.1

func NewAutoImplementationSummaryCmd() *cobra.Command

NewAutoImplementationSummaryCmd creates the hidden _auto-implementation-summary command. It is spawned as a detached background process by the worker when automations.implementation_summary is enabled and the implementation spans 2+ repos.

func NewAutoPlaybookCmd

func NewAutoPlaybookCmd() *cobra.Command

NewAutoPlaybookCmd creates the hidden _auto-playbook command. It is spawned as a detached background process by the worker when automations.playbook is enabled in settings.json.

func NewBlameCmd

func NewBlameCmd(rootOpts *RootOptions) *cobra.Command

func NewCaptureCmd

func NewCaptureCmd() *cobra.Command

NewCaptureCmd creates the `semantica capture <provider> <event-name>` command. This command is used by provider hook configurations and is not intended for interactive use.

func NewCheckpointCmd

func NewCheckpointCmd(rootOpts *RootOptions) *cobra.Command

func NewConnectCmd

func NewConnectCmd(rootOpts *RootOptions) *cobra.Command

func NewDisableCmd

func NewDisableCmd(rootOpts *RootOptions) *cobra.Command

func NewDisconnectCmd

func NewDisconnectCmd(rootOpts *RootOptions) *cobra.Command

func NewEnableCmd

func NewEnableCmd(rootOpts *RootOptions) *cobra.Command

func NewExplainCmd

func NewExplainCmd(rootOpts *RootOptions) *cobra.Command

func NewGeneratePlaybookCmd

func NewGeneratePlaybookCmd() *cobra.Command

NewGeneratePlaybookCmd creates the hidden _generate-playbook command. It is spawned as a detached background process by explain --generate.

func NewHookCmd

func NewHookCmd(rootOpts *RootOptions) *cobra.Command

func NewHookCommitMsgCmd

func NewHookCommitMsgCmd(rootOpts *RootOptions) *cobra.Command

func NewHookPostCommitCmd

func NewHookPostCommitCmd(rootOpts *RootOptions) *cobra.Command

func NewHookPreCommitCmd

func NewHookPreCommitCmd(rootOpts *RootOptions) *cobra.Command

func NewImplementationsCmd added in v0.2.0

func NewImplementationsCmd(rootOpts *RootOptions) *cobra.Command

func NewListCmd

func NewListCmd(rootOpts *RootOptions) *cobra.Command

func NewRewindCmd

func NewRewindCmd(rootOpts *RootOptions) *cobra.Command

func NewRootCmd

func NewRootCmd() *cobra.Command

func NewSessionsCmd

func NewSessionsCmd(rootOpts *RootOptions) *cobra.Command

func NewSetCmd

func NewSetCmd(rootOpts *RootOptions) *cobra.Command

func NewShowCmd

func NewShowCmd(rootOpts *RootOptions) *cobra.Command

func NewStatusCmd

func NewStatusCmd(rootOpts *RootOptions) *cobra.Command

func NewSuggestCmd

func NewSuggestCmd(rootOpts *RootOptions) *cobra.Command

func NewTidyCmd

func NewTidyCmd(rootOpts *RootOptions) *cobra.Command

func NewTranscriptsCmd

func NewTranscriptsCmd(rootOpts *RootOptions) *cobra.Command

func NewWorkerCmd

func NewWorkerCmd(rootOpts *RootOptions) *cobra.Command

func NewWorkerRunCmd

func NewWorkerRunCmd(rootOpts *RootOptions) *cobra.Command

func NewWorkspaceCmd

func NewWorkspaceCmd() *cobra.Command

NewWorkspaceCmd creates the `semantica workspace` command group.

Types

type RootOptions

type RootOptions struct {
	RepoPath string // optional override (default: cwd)
}

Jump to