Documentation
¶
Index ¶
- func Execute()
- func NewAgentsCmd(rootOpts *RootOptions) *cobra.Command
- func NewAuthCmd() *cobra.Command
- func NewAutoPlaybookCmd() *cobra.Command
- func NewBlameCmd(rootOpts *RootOptions) *cobra.Command
- func NewCaptureCmd() *cobra.Command
- func NewCheckpointCmd(rootOpts *RootOptions) *cobra.Command
- func NewConnectCmd(rootOpts *RootOptions) *cobra.Command
- func NewDisableCmd(rootOpts *RootOptions) *cobra.Command
- func NewDisconnectCmd(rootOpts *RootOptions) *cobra.Command
- func NewEnableCmd(rootOpts *RootOptions) *cobra.Command
- func NewExplainCmd(rootOpts *RootOptions) *cobra.Command
- func NewGeneratePlaybookCmd() *cobra.Command
- func NewHookCmd(rootOpts *RootOptions) *cobra.Command
- func NewHookCommitMsgCmd(rootOpts *RootOptions) *cobra.Command
- func NewHookPostCommitCmd(rootOpts *RootOptions) *cobra.Command
- func NewHookPreCommitCmd(rootOpts *RootOptions) *cobra.Command
- func NewImplementationsCmd(rootOpts *RootOptions) *cobra.Command
- func NewListCmd(rootOpts *RootOptions) *cobra.Command
- func NewRewindCmd(rootOpts *RootOptions) *cobra.Command
- func NewRootCmd() *cobra.Command
- func NewSessionsCmd(rootOpts *RootOptions) *cobra.Command
- func NewSetCmd(rootOpts *RootOptions) *cobra.Command
- func NewShowCmd(rootOpts *RootOptions) *cobra.Command
- func NewStatusCmd(rootOpts *RootOptions) *cobra.Command
- func NewSuggestCmd(rootOpts *RootOptions) *cobra.Command
- func NewTidyCmd(rootOpts *RootOptions) *cobra.Command
- func NewTranscriptsCmd(rootOpts *RootOptions) *cobra.Command
- func NewWorkerCmd(rootOpts *RootOptions) *cobra.Command
- func NewWorkerRunCmd(rootOpts *RootOptions) *cobra.Command
- func NewWorkspaceCmd() *cobra.Command
- type RootOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAgentsCmd ¶
func NewAgentsCmd(rootOpts *RootOptions) *cobra.Command
func NewAuthCmd ¶
func NewAutoPlaybookCmd ¶
NewAutoPlaybookCmd creates the hidden _auto-playbook command. It is spawned as a detached background process by the worker when automations.playbook is enabled in settings.json.
func NewBlameCmd ¶
func NewBlameCmd(rootOpts *RootOptions) *cobra.Command
func NewCaptureCmd ¶
NewCaptureCmd creates the `semantica capture <provider> <event-name>` command. This command is used by provider hook configurations and is not intended for interactive use.
func NewCheckpointCmd ¶
func NewCheckpointCmd(rootOpts *RootOptions) *cobra.Command
func NewConnectCmd ¶
func NewConnectCmd(rootOpts *RootOptions) *cobra.Command
func NewDisableCmd ¶
func NewDisableCmd(rootOpts *RootOptions) *cobra.Command
func NewDisconnectCmd ¶
func NewDisconnectCmd(rootOpts *RootOptions) *cobra.Command
func NewEnableCmd ¶
func NewEnableCmd(rootOpts *RootOptions) *cobra.Command
func NewExplainCmd ¶
func NewExplainCmd(rootOpts *RootOptions) *cobra.Command
func NewGeneratePlaybookCmd ¶
NewGeneratePlaybookCmd creates the hidden _generate-playbook command. It is spawned as a detached background process by explain --generate.
func NewHookCmd ¶
func NewHookCmd(rootOpts *RootOptions) *cobra.Command
func NewHookCommitMsgCmd ¶
func NewHookCommitMsgCmd(rootOpts *RootOptions) *cobra.Command
func NewHookPostCommitCmd ¶
func NewHookPostCommitCmd(rootOpts *RootOptions) *cobra.Command
func NewHookPreCommitCmd ¶
func NewHookPreCommitCmd(rootOpts *RootOptions) *cobra.Command
func NewImplementationsCmd ¶ added in v0.2.0
func NewImplementationsCmd(rootOpts *RootOptions) *cobra.Command
func NewListCmd ¶
func NewListCmd(rootOpts *RootOptions) *cobra.Command
func NewRewindCmd ¶
func NewRewindCmd(rootOpts *RootOptions) *cobra.Command
func NewRootCmd ¶
func NewSessionsCmd ¶
func NewSessionsCmd(rootOpts *RootOptions) *cobra.Command
func NewSetCmd ¶
func NewSetCmd(rootOpts *RootOptions) *cobra.Command
func NewShowCmd ¶
func NewShowCmd(rootOpts *RootOptions) *cobra.Command
func NewStatusCmd ¶
func NewStatusCmd(rootOpts *RootOptions) *cobra.Command
func NewSuggestCmd ¶
func NewSuggestCmd(rootOpts *RootOptions) *cobra.Command
func NewTidyCmd ¶
func NewTidyCmd(rootOpts *RootOptions) *cobra.Command
func NewTranscriptsCmd ¶
func NewTranscriptsCmd(rootOpts *RootOptions) *cobra.Command
func NewWorkerCmd ¶
func NewWorkerCmd(rootOpts *RootOptions) *cobra.Command
func NewWorkerRunCmd ¶
func NewWorkerRunCmd(rootOpts *RootOptions) *cobra.Command
func NewWorkspaceCmd ¶
NewWorkspaceCmd creates the `semantica workspace` command group.
Types ¶
type RootOptions ¶
type RootOptions struct {
RepoPath string // optional override (default: cwd)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.