Documentation
¶
Index ¶
- type Provider
- func (p *Provider) AreHooksInstalled(ctx context.Context, repoRoot string) bool
- func (p *Provider) BuildHookEvents(ctx context.Context, event *hooks.Event, bs api.BlobPutter) ([]broker.RawEvent, error)
- func (p *Provider) DeriveProviderSessionID(transcriptRef string) string
- func (p *Provider) DisplayName() string
- func (p *Provider) HookBinary(ctx context.Context, repoRoot string) (string, error)
- func (p *Provider) InstallHooks(ctx context.Context, repoRoot string, binaryPath string) (int, error)
- func (p *Provider) IsAvailable() bool
- func (p *Provider) Name() string
- func (p *Provider) ParseHookEvent(ctx context.Context, hookName string, stdin io.Reader) (*hooks.Event, error)
- func (p *Provider) ReadFromOffset(ctx context.Context, transcriptRef string, offset int, bs api.BlobPutter) ([]broker.RawEvent, int, error)
- func (p *Provider) TranscriptOffset(ctx context.Context, transcriptRef string) (int, error)
- func (p *Provider) UninstallHooks(ctx context.Context, repoRoot string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct{}
Provider implements hooks.HookProvider for Gemini CLI.
func (*Provider) AreHooksInstalled ¶
func (*Provider) BuildHookEvents ¶
func (p *Provider) BuildHookEvents(ctx context.Context, event *hooks.Event, bs api.BlobPutter) ([]broker.RawEvent, error)
BuildHookEvents constructs RawEvents directly from hook payloads. Implements hooks.DirectHookEmitter.
func (*Provider) DeriveProviderSessionID ¶
DeriveProviderSessionID returns the session ID as stored in the DB, derived from the transcript filename (e.g., "session-2026-03-24T20-29-7b235c78"). This is needed because Gemini hook payloads send raw UUIDs but ReadFromOffset uses the transcript filename stem as the provider session ID.
func (*Provider) DisplayName ¶
func (*Provider) HookBinary ¶
func (*Provider) InstallHooks ¶
func (*Provider) IsAvailable ¶
func (*Provider) ParseHookEvent ¶
func (*Provider) ReadFromOffset ¶
func (*Provider) TranscriptOffset ¶
Click to show internal directories.
Click to hide internal directories.