Documentation
¶
Index ¶
- type Provider
- func (p *Provider) AreHooksInstalled(ctx context.Context, repoRoot string) bool
- func (p *Provider) BuildHookEvents(ctx context.Context, event *hooks.Event, bs api.BlobPutter) ([]broker.RawEvent, error)
- func (p *Provider) DisplayName() string
- func (p *Provider) HookBinary(ctx context.Context, repoRoot string) (string, error)
- func (p *Provider) InstallHooks(ctx context.Context, repoRoot string, binaryPath string) (int, error)
- func (p *Provider) IsAvailable() bool
- func (p *Provider) Name() string
- func (p *Provider) ParseHookEvent(ctx context.Context, hookName string, stdin io.Reader) (*hooks.Event, error)
- func (p *Provider) ReadFromOffset(ctx context.Context, transcriptRef string, offset int, bs api.BlobPutter) ([]broker.RawEvent, int, error)
- func (p *Provider) TranscriptOffset(ctx context.Context, transcriptRef string) (int, error)
- func (p *Provider) UninstallHooks(ctx context.Context, repoRoot string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct {
// contains filtered or unexported fields
}
Provider implements hooks.HookProvider for Kiro CLI.
func (*Provider) AreHooksInstalled ¶
func (*Provider) BuildHookEvents ¶
func (p *Provider) BuildHookEvents(ctx context.Context, event *hooks.Event, bs api.BlobPutter) ([]broker.RawEvent, error)
BuildHookEvents constructs RawEvents directly from hook payloads. Implements hooks.DirectHookEmitter.
func (*Provider) DisplayName ¶
func (*Provider) HookBinary ¶
func (*Provider) InstallHooks ¶
func (*Provider) IsAvailable ¶
func (*Provider) ParseHookEvent ¶
func (p *Provider) ParseHookEvent(ctx context.Context, hookName string, stdin io.Reader) (*hooks.Event, error)
ParseHookEvent parses the Kiro CLI hook payload.
func (*Provider) ReadFromOffset ¶
func (p *Provider) ReadFromOffset(ctx context.Context, transcriptRef string, offset int, bs api.BlobPutter) ([]broker.RawEvent, int, error)
ReadFromOffset returns file-writing tool calls that occur after the saved sidecar marker.
func (*Provider) TranscriptOffset ¶
TranscriptOffset returns the current number of file-writing tool calls in the conversation. ReadFromOffset uses the sidecar marker to select new calls on the stop hook.
Click to show internal directories.
Click to hide internal directories.