Documentation
¶
Overview ¶
Package providers builds the provider registries used by the CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewHookRegistry ¶
NewHookRegistry returns all hook providers supported by the CLI. Registry.List returns them in canonical order.
func NewWriterRegistry ¶
func NewWriterRegistry() *llm.WriterRegistry
NewWriterRegistry returns the CLI's LLM writers in fallback order. The first available writer to complete successfully wins.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.